pkgdown/extra-head.html

Skip to contents

Sidebar behavior: icon-only collapse + hover expand + ellipsis labels

Usage

use_dash_sidebar_behavior(topbar_h = 56, collapsed_w = 4.2, expanded_w = 250)

Arguments

topbar_h

Height in px for navbar and sidebar brand strip

collapsed_w

Width for icon-only sidebar (rem)

expanded_w

Expanded sidebar width (px)

Value

A shiny.tag or shiny.tag.list containing sidebar behavior dependencies to include in the UI.