Checks that each direct child supplied to bs4DashNavbar(rightUi = ...)
is a complete navbar list item with the dropdown class expected by
bs4Dash/AdminLTE.
Arguments
- rightUi
A
shiny::tagList()or tag intended forbs4DashNavbar(rightUi = ...).
pkgdown/extra-head.html
Skip to contentsChecks that each direct child supplied to bs4DashNavbar(rightUi = ...)
is a complete navbar list item with the dropdown class expected by
bs4Dash/AdminLTE.
A shiny::tagList() or tag intended for
bs4DashNavbar(rightUi = ...).