Creates a reusable brand configuration that can be converted to
dash_titles() output with dash_titles_from().
Usage
dash_brand_options(
name,
icon = NULL,
collapsed = NULL,
expanded = NULL,
app_name = NULL,
collapsed_mode = NULL,
expanded_mode = NULL,
...
)Arguments
- name
Visible brand label.
- icon
Font Awesome icon name or simple
shiny::icon()tag.- collapsed
Short label used when the sidebar brand is collapsed.
- expanded
Label used when the sidebar brand is expanded.
- app_name
Browser tab title.
- collapsed_mode
Sidebar brand mode when collapsed. If
NULL,dash_titles()uses its normal default.- expanded_mode
Sidebar brand mode when expanded. If
NULL,dash_titles()uses its normal default.- ...
Additional options forwarded to
dash_titles()bydash_titles_from().